==> org.eclipse.papyrus.toolsmiths.validation.common.source_2.0.0.202109161320.jar: org/eclipse/papyrus/toolsmiths/validation/common/internal/messages/Messages.java <==
/*****************************************************************************
 * Copyright (c) 2021 Christian W. Damus, CEA LIST, and others.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Christian W. Damus - Initial API and implementation
 *
 *****************************************************************************/

package org.eclipse.papyrus.toolsmiths.validation.common.internal.messages;

import org.eclipse.osgi.util.NLS;

/**
 * @author damus
 *
 */
public class Messages extends NLS {
	private static final String BUNDLE_NAME = "org.eclipse.papyrus.toolsmiths.validation.common.internal.messages.messages"; //$NON-NLS-1$
	public static String BasicEMFResourceProvider_0;
	public static String BasicEMFResourceProvider_1;
	public static String BasicPluginXMLResourceProvider_0;
	public static String BasicPluginXMLResourceProvider_1;
	public static String BuildPropertiesChecker_2;
	public static String BuildPropertiesChecker_3;
	public static String CustomModelChecker_0;
	public static String ExtensionsChecker_0;
	public static String ExtensionsChecker_1;
	public static String ModelDependenciesChecker_0;
	public static String ModelDependenciesChecker_1;
	public static String ModelDependenciesChecker_2;
	public static String PluginErrorReporter_0;
	public static String MissingDependenciesMarkerResolution_description;
	public static String MissingDependenciesMarkerResolution_label;
	public static String ResourceKind_0;
	public static String ResourceKind_1;
	public static String ResourceKind_2;
	public static String ResourceKind_3;
	public static String ResourceMissingFromBinaryBuildMarkerResolution_description;
	public static String ResourceMissingFromBinaryBuildMarkerResolution_label;
	public static String ResourceMissingFromBinaryBuildMarkerResolution_folder;
	public static String ResourceMissingFromBinaryBuildMarkerResolution_file;
	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}

==> org.eclipse.papyrus.toolsmiths.validation.common.source_2.0.0.202112011052.jar: org/eclipse/papyrus/toolsmiths/validation/common/internal/messages/Messages.java <==
/*****************************************************************************
 * Copyright (c) 2021 Christian W. Damus, CEA LIST, and others.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Christian W. Damus - Initial API and implementation
 *
 *****************************************************************************/

package org.eclipse.papyrus.toolsmiths.validation.common.internal.messages;

import org.eclipse.osgi.util.NLS;

/**
 * @author damus
 *
 */
public class Messages extends NLS {
	private static final String BUNDLE_NAME = "org.eclipse.papyrus.toolsmiths.validation.common.internal.messages.messages"; //$NON-NLS-1$
	public static String BasicEMFResourceProvider_0;
	public static String BasicEMFResourceProvider_1;
	public static String BasicPluginXMLResourceProvider_0;
	public static String BasicPluginXMLResourceProvider_1;
	public static String BuildPropertiesChecker_2;
	public static String BuildPropertiesChecker_3;
	public static String CommonMarkerResolutionUtils_0;
	public static String CommonMarkerResolutionUtils_1;
	public static String CommonURIUtils_0;
	public static String CustomModelChecker_0;
	public static String ExtensionsChecker_0;
	public static String ExtensionsChecker_1;
	public static String ModelDependenciesChecker_0;
	public static String ModelDependenciesChecker_1;
	public static String PluginErrorReporter_0;
	public static String MissingDependenciesMarkerResolution_description;
	public static String MissingDependenciesMarkerResolution_label;
	public static String ResourceKind_0;
	public static String ResourceKind_1;
	public static String ResourceKind_2;
	public static String ResourceKind_3;
	public static String ResourceMissingFromBinaryBuildMarkerResolution_description;
	public static String ResourceMissingFromBinaryBuildMarkerResolution_label;
	public static String ResourceMissingFromBinaryBuildMarkerResolution_folder;
	public static String ResourceMissingFromBinaryBuildMarkerResolution_file;
	public static String SimpleModelEditMarkerResolution_0;
	public static String TouchResourceCommand_0;
	public static String TouchResourceCommand_1;
	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}
